# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`memcached`](#memcached): This class manages memcached
* [`memcached::params`](#memcached--params): == Class: memcached::params

#### Private Classes

* `memcached::instance::servicefile`: helper class to configure the memcache multiinstance unit file *once*

### Defined types

* [`memcached::instance`](#memcached--instance): Manage multiple memcached instances

### Functions

* [`memcached::max_memory`](#memcached--max_memory): Calculate max_memory size from fact 'memsize' and passed argument.

## Classes

### <a name="memcached"></a>`memcached`

This class manages memcached

#### Examples

##### Use default settings

```puppet
include memcached
```

#### Parameters

The following parameters are available in the `memcached` class:

* [`package_ensure`](#-memcached--package_ensure)
* [`service_manage`](#-memcached--service_manage)
* [`service_flags`](#-memcached--service_flags)
* [`logfile`](#-memcached--logfile)
* [`logstdout`](#-memcached--logstdout)
* [`syslog`](#-memcached--syslog)
* [`pidfile`](#-memcached--pidfile)
* [`manage_firewall`](#-memcached--manage_firewall)
* [`max_memory`](#-memcached--max_memory)
* [`max_item_size`](#-memcached--max_item_size)
* [`min_item_size`](#-memcached--min_item_size)
* [`factor`](#-memcached--factor)
* [`lock_memory`](#-memcached--lock_memory)
* [`listen`](#-memcached--listen)
* [`listen_ip`](#-memcached--listen_ip)
* [`tcp_port`](#-memcached--tcp_port)
* [`udp_port`](#-memcached--udp_port)
* [`user`](#-memcached--user)
* [`max_connections`](#-memcached--max_connections)
* [`verbosity`](#-memcached--verbosity)
* [`unix_socket`](#-memcached--unix_socket)
* [`unix_socket_mask`](#-memcached--unix_socket_mask)
* [`install_dev`](#-memcached--install_dev)
* [`processorcount`](#-memcached--processorcount)
* [`service_restart`](#-memcached--service_restart)
* [`auto_removal`](#-memcached--auto_removal)
* [`use_sasl`](#-memcached--use_sasl)
* [`use_tls`](#-memcached--use_tls)
* [`tls_cert_chain`](#-memcached--tls_cert_chain)
* [`tls_key`](#-memcached--tls_key)
* [`tls_ca_cert`](#-memcached--tls_ca_cert)
* [`tls_verify_mode`](#-memcached--tls_verify_mode)
* [`use_registry`](#-memcached--use_registry)
* [`registry_key`](#-memcached--registry_key)
* [`large_mem_pages`](#-memcached--large_mem_pages)
* [`use_svcprop`](#-memcached--use_svcprop)
* [`svcprop_fmri`](#-memcached--svcprop_fmri)
* [`svcprop_key`](#-memcached--svcprop_key)
* [`extended_opts`](#-memcached--extended_opts)
* [`config_tmpl`](#-memcached--config_tmpl)
* [`disable_cachedump`](#-memcached--disable_cachedump)
* [`max_reqs_per_event`](#-memcached--max_reqs_per_event)
* [`disable_flush_all`](#-memcached--disable_flush_all)
* [`disable_watch`](#-memcached--disable_watch)
* [`memory_file`](#-memcached--memory_file)

##### <a name="-memcached--package_ensure"></a>`package_ensure`

Data type: `Enum['present', 'latest', 'absent']`

Set ensure of the memcached package

Default value: `'present'`

##### <a name="-memcached--service_manage"></a>`service_manage`

Data type: `Boolean`

Manage the memcached service

Default value: `true`

##### <a name="-memcached--service_flags"></a>`service_flags`

Data type: `Optional[String]`

Pass flags to the service managed by Puppet

Default value: `$memcached::params::service_flags`

##### <a name="-memcached--logfile"></a>`logfile`

Data type: `Optional[Stdlib::Absolutepath]`

Specify file to log to. Not supported on OS using systemd

Default value: `$memcached::params::logfile`

##### <a name="-memcached--logstdout"></a>`logstdout`

Data type: `Boolean`

Disable logging to a file or syslog entirely. Only supported on RedHat-based OS and Suse

Default value: `false`

##### <a name="-memcached--syslog"></a>`syslog`

Data type: `Boolean`

Log to syslog. Only supported on RedHat-based OS and Suse

Default value: `false`

##### <a name="-memcached--pidfile"></a>`pidfile`

Data type: `Variant[Stdlib::Absolutepath, Boolean[false], Undef]`

Save pid in file

Default value: `$memcached::params::pidfile`

##### <a name="-memcached--manage_firewall"></a>`manage_firewall`

Data type: `Boolean`

Create simple firewall rules. Only supported on Linux

Default value: `false`

##### <a name="-memcached--max_memory"></a>`max_memory`

Data type: `Variant[Integer[0], Pattern[/^1?\d?\d%$/]]`

Max memory memcached should use to store items. Either in percent or mb

Default value: `'95%'`

##### <a name="-memcached--max_item_size"></a>`max_item_size`

Data type: `Optional[Variant[Integer, String]]`

Adjusts max item size

Default value: `undef`

##### <a name="-memcached--min_item_size"></a>`min_item_size`

Data type: `Optional[Variant[Integer, String]]`

Min space used for key+value+flags

Default value: `undef`

##### <a name="-memcached--factor"></a>`factor`

Data type: `Optional[Variant[Integer, String]]`

Chunk size growth factor

Default value: `undef`

##### <a name="-memcached--lock_memory"></a>`lock_memory`

Data type: `Boolean`

Lock down all paged memory

Default value: `false`

##### <a name="-memcached--listen"></a>`listen`

Data type: `Optional[Variant[String,Array[String]]]`

Interface to listen on

Default value: `undef`

##### <a name="-memcached--listen_ip"></a>`listen_ip`

Data type: `Optional[Variant[Stdlib::IP::Address,Array[Stdlib::IP::Address]]]`

Deprecated. Use `listen` instead

Default value: `undef`

##### <a name="-memcached--tcp_port"></a>`tcp_port`

Data type: `Integer`

TCP port to listen on

Default value: `11211`

##### <a name="-memcached--udp_port"></a>`udp_port`

Data type: `Integer`

UDP port to listen on

Default value: `0`

##### <a name="-memcached--user"></a>`user`

Data type: `String`

User to run memcached service as

Default value: `$memcached::params::user`

##### <a name="-memcached--max_connections"></a>`max_connections`

Data type: `Integer`

Max simultaneous connections

Default value: `8192`

##### <a name="-memcached--verbosity"></a>`verbosity`

Data type: `Optional[Enum['v', 'vv', 'vvv']]`

v: verbose (print errors/warnings while in event loop)
vv: very verbose (also print client commands/responses)
vvv: extremely verbose (internal state transitions)

Default value: `undef`

##### <a name="-memcached--unix_socket"></a>`unix_socket`

Data type: `Optional[String]`

UNIX socket to listen on (disables network support)

Default value: `undef`

##### <a name="-memcached--unix_socket_mask"></a>`unix_socket_mask`

Data type: `String`

access mask for UNIX socket, in octal

Default value: `'0755'`

##### <a name="-memcached--install_dev"></a>`install_dev`

Data type: `Boolean`

Manage installation of the memcached dev package

Default value: `false`

##### <a name="-memcached--processorcount"></a>`processorcount`

Data type: `Variant[String,Integer]`

Number of threads to use

Default value: `$facts['processors']['count']`

##### <a name="-memcached--service_restart"></a>`service_restart`

Data type: `Boolean`

Whether or not to restart the memcached service on changes

Default value: `true`

##### <a name="-memcached--auto_removal"></a>`auto_removal`

Data type: `Boolean`

Return error on memory exhausted instead of evicting

Default value: `false`

##### <a name="-memcached--use_sasl"></a>`use_sasl`

Data type: `Boolean`

Turn on SASL authentication

Default value: `false`

##### <a name="-memcached--use_tls"></a>`use_tls`

Data type: `Boolean`

Enable TLS/SSL

Default value: `false`

##### <a name="-memcached--tls_cert_chain"></a>`tls_cert_chain`

Data type: `Optional[Stdlib::Absolutepath]`

Path to certificate chain file

Default value: `undef`

##### <a name="-memcached--tls_key"></a>`tls_key`

Data type: `Optional[Stdlib::Absolutepath]`

Path to certificate key file

Default value: `undef`

##### <a name="-memcached--tls_ca_cert"></a>`tls_ca_cert`

Data type: `Optional[Stdlib::Absolutepath]`

Path to CA certificate file

Default value: `undef`

##### <a name="-memcached--tls_verify_mode"></a>`tls_verify_mode`

Data type: `Integer[0,3]`

Peer certificate verify mode

Default value: `1`

##### <a name="-memcached--use_registry"></a>`use_registry`

Data type: `Boolean`



Default value: `$memcached::params::use_registry`

##### <a name="-memcached--registry_key"></a>`registry_key`

Data type: `String`



Default value: `'HKLM\System\CurrentControlSet\services\memcached\ImagePath'`

##### <a name="-memcached--large_mem_pages"></a>`large_mem_pages`

Data type: `Boolean`

Try to use large memory pages (if available)

Default value: `false`

##### <a name="-memcached--use_svcprop"></a>`use_svcprop`

Data type: `Boolean`



Default value: `$memcached::params::use_svcprop`

##### <a name="-memcached--svcprop_fmri"></a>`svcprop_fmri`

Data type: `String`



Default value: `'memcached:default'`

##### <a name="-memcached--svcprop_key"></a>`svcprop_key`

Data type: `String`



Default value: `'memcached/options'`

##### <a name="-memcached--extended_opts"></a>`extended_opts`

Data type: `Optional[Array[String]]`

Array of extended options

Default value: `undef`

##### <a name="-memcached--config_tmpl"></a>`config_tmpl`

Data type: `String`

Use a different config template

Default value: `$memcached::params::config_tmpl`

##### <a name="-memcached--disable_cachedump"></a>`disable_cachedump`

Data type: `Boolean`

Disable stats cachedump and lru_crawler metadump

Default value: `false`

##### <a name="-memcached--max_reqs_per_event"></a>`max_reqs_per_event`

Data type: `Optional[Integer]`

Maximum number of requests per event, limits the
requests processed per connection to prevent starvation

Default value: `undef`

##### <a name="-memcached--disable_flush_all"></a>`disable_flush_all`

Data type: `Boolean`

Disable flush_all command

Default value: `false`

##### <a name="-memcached--disable_watch"></a>`disable_watch`

Data type: `Boolean`

Disable watch commands (live logging)

Default value: `false`

##### <a name="-memcached--memory_file"></a>`memory_file`

Data type: `Optional[Stdlib::Absolutepath]`

mmap a file for item memory.

Default value: `undef`

### <a name="memcached--params"></a>`memcached::params`

== Class: memcached::params

## Defined types

### <a name="memcached--instance"></a>`memcached::instance`

Manage multiple memcached instances

#### Parameters

The following parameters are available in the `memcached::instance` defined type:

* [`manage_firewall`](#-memcached--instance--manage_firewall)
* [`port`](#-memcached--instance--port)
* [`limits`](#-memcached--instance--limits)
* [`override_content`](#-memcached--instance--override_content)
* [`override_source`](#-memcached--instance--override_source)

##### <a name="-memcached--instance--manage_firewall"></a>`manage_firewall`

Data type: `Boolean`

enable/disable fireall management via puppetlabs/firewall

Default value: `false`

##### <a name="-memcached--instance--port"></a>`port`

Data type: `Stdlib::Port::Unprivileged`

the udp and tcp port to listen on. By default, the instance name is used

Default value: `Integer($name)`

##### <a name="-memcached--instance--limits"></a>`limits`

Data type: `Optional[Systemd::ServiceLimits]`

systemd limits for the service

Default value: `undef`

##### <a name="-memcached--instance--override_content"></a>`override_content`

Data type: `Optional[String[1]]`

overrides for the unit, as string

Default value: `undef`

##### <a name="-memcached--instance--override_source"></a>`override_source`

Data type: `Optional[Stdlib::Filesource]`

overrides for the unit, as file resource

Default value: `undef`

## Functions

### <a name="memcached--max_memory"></a>`memcached::max_memory`

Type: Ruby 4.x API

Calculate max_memory size from fact 'memsize' and passed argument.

#### `memcached::max_memory(Any $arg)`

Calculate max_memory size from fact 'memsize' and passed argument.

Returns: `Integer`

##### `arg`

Data type: `Any`



